class RbiphonetestGenerator < RubiGen::Base

  DEFAULT_SHEBANG = File.join(Config::CONFIG['bindir'],
                              Config::CONFIG['ruby_install_name'])

  default_options :author => nil,
                  :test_framework => 'test_unit'

  attr_reader :name, :child_model, :parent_model, :module_name
  attr_reader :test_framework



  def initialize(runtime_args, runtime_options = {})
    super
    usage if args.empty?
    @destination_root = File.expand_path(args.shift)
    @name             = base_name.gsub("-", "_")
    @child_model = "Booklist"
    @parent_model = "User"
    @module_name = "Person"

    extract_options
  end

  def manifest
    record do |m|
      # Ensure appropriate folder(s) exists
      m.directory ''
      BASEDIRS.each { |path| m.directory path }

      # Create stubs
      m.template_copy_each ["Rakefile"]
      m.file    "dot_autotest", ".autotest"
      m.template "Classes/AddDogViewController.m.erb", "Classes/Add#{child_model}ViewController.m"
      m.template "Classes/AddDogViewController.h.erb", "Classes/Add#{child_model}ViewController.h"                            
      m.template "Classes/AddPersonViewController.m.erb", "Classes/Add#{parent_model}ViewController.m"
      m.template "Classes/AddPersonViewController.h.erb", "Classes/Add#{parent_model}ViewController.h"
      m.template "Classes/Dog.m.erb", "Classes/#{child_model}.m"
      m.template "Classes/Dog.h.erb", "Classes/#{child_model}.h"
      m.template "Classes/DogErrorTest.h.erb", "Classes/#{child_model}ErrorTest.h"
      m.template "Classes/DogErrorTest.m.erb", "Classes/#{child_model}ErrorTest.m"
      m.template "Classes/DogViewController.h.erb", "Classes/#{child_model}ViewController.h"
      m.template "Classes/DogViewController.m.erb", "Classes/#{child_model}ViewController.m"
      m.template "Classes/EditDogViewController.h.erb", "Classes/Edit#{child_model}ViewController.h"
      m.template "Classes/EditDogViewController.m.erb", "Classes/Edit#{child_model}ViewController.m"
      m.template "Classes/EditPerson.h.erb", "Classes/Edit#{parent_model}.h"
      m.template "Classes/EditPerson.m.erb", "Classes/Edit#{parent_model}.m"
      m.template "Classes/EditPersonController.h.erb", "Classes/Edit#{parent_model}Controller.h"
      m.template "Classes/EditPersonController.m.erb", "Classes/Edit#{parent_model}Controller.m"
      m.template "Classes/PeopleViewController.h.erb", "Classes/#{parent_model.pluralize}ViewController.h"
      m.template "Classes/PeopleViewController.m.erb", "Classes/#{parent_model.pluralize}ViewController.m"
     # m.template "Classes/PersonViewController.h.erb", "Classes/#{parent_model}ViewController.h"
      #m.template "Classes/PeopleViewController.m.erb", "Classes/#{parent_model}ViewController.m"
      m.template "Classes/PrefixedPerson.h.erb", "Classes/Prefixed#{parent_model}.h"
      m.template "Classes/ViewDogController.h.erb", "Classes/View#{child_model}Controller.h"
      m.template "Classes/ViewDogController.m.erb", "Classes/View#{child_model}Controller.m"
      m.template "Classes/ViewPersonController.h.erb", "Classes/View#{parent_model}Controller.h"
      m.template "Classes/ViewPersonController.m.erb", "Classes/View#{parent_model}Controller.m"      
      m.template "Classes/Person.h.erb", "Classes/#{parent_model}.h"
      m.template "Classes/Person.m.erb", "Classes/#{parent_model}.m"

      
    end
  end

  protected
    def banner
      <<-EOS
Want to write iPhone unit tests? Want to write them in Ruby? 
Run this generator in the root folder of your Xcode project for your iPhone app.

USAGE: #{spec.name} name
EOS
    end

    def add_options!(opts)
      opts.separator ''
      opts.separator 'Options:'
      # For each option below, place the default
      # at the top of the file next to "default_options"
      opts.on("-s", "--test-with=TEST_FRAMEWORK", String,
              "Select your preferred testing framework.",
              "Options: test_unit (default), rspec.") { |x| options[:test_framework] = x }
      opts.on("-v", "--version", "Show the #{File.basename($0)} version number and quit.")
    end

    def extract_options
      # for each option, extract it into a local variable (and create an "attr_reader :author" at the top)
      # Templates can access these value via the attr_reader-generated methods, but not the
      # raw instance variable value.
      # @author = options[:author]
      @test_framework    = options[:test_framework] || "test_unit"
    end

    # Installation skeleton.  Intermediate directories are automatically
    # created so don't sweat their absence here.
    BASEDIRS = %w(
      Classes
      tasks
    )
end
